==> activity-center-api-1.2.10.3-20161130.022354-1-sources.jar: cn/com/duiba/activity/center/api/remoteservice/seckill/RemoteDuibaSeckillServiceNew.java <==
package cn.com.duiba.activity.center.api.remoteservice.seckill;

import cn.com.duiba.activity.center.api.dto.quizz.AddActivityDto;
import cn.com.duiba.activity.center.api.dto.seckill.DuibaSeckillDto;

import java.util.List;
import java.util.Map;

public interface RemoteDuibaSeckillServiceNew {

	/**
	 * 批量查询秒杀活动
	 *
	 * @author zhanglihui
	 * @param ids
	 * @return
	 * @since JDK 1.6
	 */
	List<DuibaSeckillDto> findAllOpenedByIds(List<Long> ids);

	public DuibaSeckillDto insert(DuibaSeckillDto duibaSeckillDO);
	public List<DuibaSeckillDto> findByPage(Map<String, Object> queryMap);
	public Long findPageCount();
	public Long findPageCount(Map<String, Object> queryMap);
	public DuibaSeckillDto find(Long id);
	public String findTagById(Long id);
	public List<DuibaSeckillDto> findEffective();
	public int updateStatus(Long id, int status);
	public int updateTagById(Long id, String tag);
	public int delete(Long id);
	public int updateAutoOffDateNull(Long id);
	public int updateInfoForm(DuibaSeckillDto duibaSeckillDO);

	public void updateSwitches(Long id, Long switches);
	
	/**
	 * 查询秒杀活动列表.<br>
	 * 【查询参数】
	 * <ol>
	 * <li>offset:查询的开始位置处</li>
	 * <li>max:偏移量</li>
	 * <li>activityName:title名称(支持模糊查询)</li>
	 * <li>activityId:秒杀活动ID</li>
	 * </ol>
	 *
	 * @param queryMap 查询参数
	 * @param List<DuibaSeckillDto> 秒杀活动概要信息
	 *
	 */
	public List<DuibaSeckillDto> findByMap(Map<String, Object> paramMap);

	public List<DuibaSeckillDto> findAllByIds(List<Long> ids);

	public List<AddActivityDto> findAllSeckill(Long appId);

	public void update(DuibaSeckillDto DO);

}

==> activity-center-api-1.2.13.1-20170116.063249-1-sources.jar: cn/com/duiba/activity/center/api/remoteservice/seckill/RemoteDuibaSeckillServiceNew.java <==
package cn.com.duiba.activity.center.api.remoteservice.seckill;

import cn.com.duiba.activity.center.api.dto.quizz.AddActivityDto;
import cn.com.duiba.activity.center.api.dto.seckill.DuibaSeckillDto;

import java.util.List;
import java.util.Map;

/**
 * 
 * ClassName: RemoteDuibaSeckillServiceNew <br/>
 * date: 2016年12月1日 下午5:28:03 <br/>
 *
 * @version 
 * @since JDK 1.6
 */
public interface RemoteDuibaSeckillServiceNew {

    /**
     * 
     * findAllOpenedByIds:(这里用一句话描述这个方法的作用). <br/>
     * 批量查询秒杀活动
     * @param ids
     * @return
     * @since JDK 1.6
     */
	List<DuibaSeckillDto> findAllOpenedByIds(List<Long> ids);

	/**
	 * 
	 * insert:(这里用一句话描述这个方法的作用). <br/>
	 * @param duibaSeckillDO
	 * @return
	 * @since JDK 1.6
	 */
	public DuibaSeckillDto insert(DuibaSeckillDto duibaSeckillDO);
	/**
	 * 
	 * findByPage:(这里用一句话描述这个方法的作用). <br/>
	 * @param queryMap
	 * @return
	 * @since JDK 1.6
	 */
	public List<DuibaSeckillDto> findByPage(Map<String, Object> queryMap);
	/**
	 * 
	 * findPageCount:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @return
	 * @since JDK 1.6
	 */
	public Long findPageCount();
	/**
	 * 
	 * findPageCount:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param queryMap
	 * @return
	 * @since JDK 1.6
	 */
	public Long findPageCount(Map<String, Object> queryMap);
	/**
	 * 
	 * find:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	public DuibaSeckillDto find(Long id);
	/**
	 * 
	 * findTagById:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	public String findTagById(Long id);
	/**
	 * 
	 * findEffective:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @return
	 * @since JDK 1.6
	 */
	public List<DuibaSeckillDto> findEffective();
	/**
	 * 
	 * updateStatus:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @param status
	 * @return
	 * @since JDK 1.6
	 */
	public int updateStatus(Long id, int status);
	/**
	 * 
	 * updateTagById:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @param tag
	 * @return
	 * @since JDK 1.6
	 */
	public int updateTagById(Long id, String tag);
	/**
	 * 
	 * delete:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	public int delete(Long id);
	/**
	 * 
	 * updateAutoOffDateNull:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	public int updateAutoOffDateNull(Long id);
	/**
	 * 
	 * updateInfoForm:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param duibaSeckillDO
	 * @return
	 * @since JDK 1.6
	 */
	public int updateInfoForm(DuibaSeckillDto duibaSeckillDO);

	/**
	 * 
	 * updateSwitches:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param id
	 * @param switches
	 * @since JDK 1.6
	 */
	public void updateSwitches(Long id, Long switches);
	
	/**
	 * 
	 * findByMap:(这里用一句话描述这个方法的作用). <br/>
	 * 查询秒杀活动列表
	 * @param paramMap
	 * @return
	 * @since JDK 1.6
	 */
	public List<DuibaSeckillDto> findByMap(Map<String, Object> paramMap);

	/**
	 * 
	 * findAllByIds:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param ids
	 * @return
	 * @since JDK 1.6
	 */
	public List<DuibaSeckillDto> findAllByIds(List<Long> ids);

	/**
	 * 
	 * findAllSeckill:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param appId
	 * @return
	 * @since JDK 1.6
	 */
	public List<AddActivityDto> findAllSeckill(Long appId);

	/**
	 * 
	 * update:(这里用一句话描述这个方法的作用). <br/>
	 * 
	 * @param DO
	 * @since JDK 1.6
	 */
	public void update(DuibaSeckillDto DO);

}
